@@ -50,8 +50,8 @@ func (e *Executor) compiledTask(call taskfile.Call, evaluateShVars bool) (*taskf
 		Prompt:               r.Replace(origTask.Prompt),
 		Summary:              r.Replace(origTask.Summary),
 		Aliases:              origTask.Aliases,
-		Sources:              r.ReplaceSlice(origTask.Sources),
-		Generates:            r.ReplaceSlice(origTask.Generates),
+		Sources:              r.ReplaceGlobs(origTask.Sources),
+		Generates:            r.ReplaceGlobs(origTask.Generates),
 		Dir:                  r.Replace(origTask.Dir),
 		Set:                  origTask.Set,
 		Shopt:                origTask.Shopt,
